starcluster.plugins.PluginRegistry

Package starcluster :: Package plugins :: Class PluginRegistry |
[hide private]
[frames] | no frames]

# Class PluginRegistry

source code

Keeps track of all built-in and user-installed plugins

Instance Methods | [hide private]
__init__(self, plugin_dir=`'``/home/jtriley/.starcluster/plugins``'`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_get_modules_in_dir(self, package) | source code
module_classes(self, module_path) | source code
pkg_classes(self, package) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| builtin_plugins
| user_plugins
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, plugin_dir=`'``/home/jtriley/.starcluster/plugins``'`) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Property Details | [hide private]

### builtin_plugins Get Method: unreachable.builtin_plugins(self)

### user_plugins Get Method: unreachable.user_plugins(self)